package cn.com.infosec.mobile.android.xlog.internal.util;

import android.content.ComponentName;
import android.content.Intent;
import android.graphics.Rect;
import android.net.Uri;
import android.os.Bundle;
import android.os.Parcelable;
import android.os.Build.VERSION;
import android.support.annotation.Keep;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.Arrays;
import java.util.Iterator;
import java.util.Set;

@Keep
public class ObjectToStringUtil {
   public static String bundleToString(Bundle bundle) {
      if (bundle == null) {
         return "null";
      } else {
         StringBuilder var10000 = new StringBuilder(128);
         var10000.append("Bundle[{");
         bundleToShortString(bundle, var10000);
         var10000.append("}]");
         return var10000.toString();
      }
   }

   public static String intentToString(Intent intent) {
      if (intent == null) {
         return "null";
      } else {
         StringBuilder var10000 = new StringBuilder(128);
         var10000.append("Intent { ");
         intentToShortString(intent, var10000);
         var10000.append(" }");
         return var10000.toString();
      }
   }

   private static void bundleToShortString(Bundle bundle, StringBuilder b) {
      boolean var2 = true;

      for(Iterator var3 = bundle.keySet().iterator(); var3.hasNext(); var2 = false) {
         boolean var10000 = var2;
         String var4 = (String)var3.next();
         if (!var10000) {
            b.append(", ");
         }

         b.append(var4).append('=');
         Object var5;
         if ((var5 = bundle.get(var4)) instanceof int[]) {
            b.append(Arrays.toString((int[])var5));
         } else if (var5 instanceof byte[]) {
            b.append(Arrays.toString((byte[])var5));
         } else if (var5 instanceof boolean[]) {
            b.append(Arrays.toString((boolean[])var5));
         } else if (var5 instanceof short[]) {
            b.append(Arrays.toString((short[])var5));
         } else if (var5 instanceof long[]) {
            b.append(Arrays.toString((long[])var5));
         } else if (var5 instanceof float[]) {
            b.append(Arrays.toString((float[])var5));
         } else if (var5 instanceof double[]) {
            b.append(Arrays.toString((double[])var5));
         } else if (var5 instanceof String[]) {
            b.append(Arrays.toString((String[])var5));
         } else if (var5 instanceof CharSequence[]) {
            b.append(Arrays.toString((CharSequence[])var5));
         } else if (var5 instanceof Parcelable[]) {
            b.append(Arrays.toString((Parcelable[])var5));
         } else if (var5 instanceof Bundle) {
            b.append(bundleToString((Bundle)var5));
         } else {
            b.append(var5);
         }
      }

   }

   private static void intentToShortString(Intent intent, StringBuilder b) {
      boolean var2 = true;
      String var3;
      if ((var3 = intent.getAction()) != null) {
         b.append("act=").append(var3);
         var2 = false;
      }

      Set var5;
      if ((var5 = intent.getCategories()) != null) {
         if (!var2) {
            b.append(' ');
         }

         Set var10000 = var5;
         var2 = false;
         b.append("cat=[");
         boolean var6 = true;

         for(Iterator var4 = var10000.iterator(); var4.hasNext(); var6 = false) {
            boolean var13 = var6;
            var3 = (String)var4.next();
            if (!var13) {
               b.append(',');
            }

            b.append(var3);
         }

         b.append("]");
      }

      Uri var8;
      if ((var8 = intent.getData()) != null) {
         if (!var2) {
            b.append(' ');
         }

         var2 = false;
         b.append("dat=");
         if (VERSION.SDK_INT >= 14) {
            b.append(uriToSafeString(var8));
         } else {
            String var7;
            if ((var7 = var8.getScheme()) != null) {
               if (var7.equalsIgnoreCase("tel")) {
                  b.append("tel:xxx-xxx-xxxx");
               } else if (var7.equalsIgnoreCase("smsto")) {
                  b.append("smsto:xxx-xxx-xxxx");
               } else {
                  b.append(var8);
               }
            } else {
               b.append(var8);
            }
         }
      }

      if ((var3 = intent.getType()) != null) {
         if (!var2) {
            b.append(' ');
         }

         var2 = false;
         b.append("typ=").append(var3);
      }

      int var10;
      if ((var10 = intent.getFlags()) != 0) {
         if (!var2) {
            b.append(' ');
         }

         var2 = false;
         b.append("flg=0x").append(Integer.toHexString(var10));
      }

      if ((var3 = intent.getPackage()) != null) {
         if (!var2) {
            b.append(' ');
         }

         var2 = false;
         b.append("pkg=").append(var3);
      }

      ComponentName var11;
      if ((var11 = intent.getComponent()) != null) {
         if (!var2) {
            b.append(' ');
         }

         var2 = false;
         b.append("cmp=").append(var11.flattenToShortString());
      }

      Rect var12;
      if ((var12 = intent.getSourceBounds()) != null) {
         if (!var2) {
            b.append(' ');
         }

         var2 = false;
         b.append("bnds=").append(var12.toShortString());
      }

      if ((var10 = VERSION.SDK_INT) >= 16 && intent.getClipData() != null) {
         if (!var2) {
            b.append(' ');
         }

         var2 = false;
         b.append("(has clip)");
      }

      Bundle var9;
      if ((var9 = intent.getExtras()) != null) {
         if (!var2) {
            b.append(' ');
         }

         b.append("extras={");
         bundleToShortString(var9, b);
         b.append('}');
      }

      if (var10 >= 15 && (intent = intent.getSelector()) != null) {
         b.append(" sel=");
         intentToShortString(intent, b);
         b.append("}");
      }

   }

   private static String uriToSafeString(Uri uri) {
      if (VERSION.SDK_INT >= 14) {
         NoSuchMethodException var12;
         label59: {
            InvocationTargetException var11;
            label60: {
               IllegalAccessException var10000;
               label52: {
                  Class var13;
                  boolean var10001;
                  try {
                     var13 = Uri.class;
                  } catch (NoSuchMethodException var8) {
                     var12 = var8;
                     var10001 = false;
                     break label59;
                  } catch (InvocationTargetException var9) {
                     var11 = var9;
                     var10001 = false;
                     break label60;
                  } catch (IllegalAccessException var10) {
                     var10000 = var10;
                     var10001 = false;
                     break label52;
                  }

                  String var14 = "toSafeString";

                  Method var15;
                  try {
                     var15 = var13.getDeclaredMethod(var14);
                  } catch (NoSuchMethodException var5) {
                     var12 = var5;
                     var10001 = false;
                     break label59;
                  } catch (InvocationTargetException var6) {
                     var11 = var6;
                     var10001 = false;
                     break label60;
                  } catch (IllegalAccessException var7) {
                     var10000 = var7;
                     var10001 = false;
                     break label52;
                  }

                  Method var16 = var15;

                  try {
                     var16.setAccessible(true);
                     return (String)var15.invoke(uri);
                  } catch (NoSuchMethodException var2) {
                     var12 = var2;
                     var10001 = false;
                     break label59;
                  } catch (InvocationTargetException var3) {
                     var11 = var3;
                     var10001 = false;
                     break label60;
                  } catch (IllegalAccessException var4) {
                     var10000 = var4;
                     var10001 = false;
                  }
               }

               var10000.printStackTrace();
               return uri.toString();
            }

            var11.printStackTrace();
            return uri.toString();
         }

         var12.printStackTrace();
      }

      return uri.toString();
   }
}
